#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 17/11/2002
#################################################################################
#
# Guest - Script part of Webchat designed to lead guests to rooms
# Copyright (C) 2000-2002  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 204 - 817, 5th Street NE
#                 Calgary, Alberta
#                 T2E 3W9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Param;						# Parameter control
use Ethereal::Post;						# Post handler
use Ethereal::Table;						# Table handler
use Ethereal::Template;						# Template handler
use Ethereal::Who;						# Who is on


#################################################################################
# Data Members
#################################################################################
my $cgi;							# Common gateway interface handle
my $database;							# Database handle
my $param;							# Parameter handle
my $tmpl;							# Template handle

my %portal;							# Portal hash

#################################################################################
# Program Area
#################################################################################

	# Initial parameters
	$cgi      = new CGI;	
	$database = new Ethereal::Database();	


	# Safety measure
	$cgi->delete('NUM');
	$cgi->delete('READONLY');

	# Connect and fetch
	$database->Connect();

	# Parameter handling
	$param = new Ethereal::Param($database, $cgi);
	$param->GetParam();

	# Link to hash
	$database->GetHashPortal(\%portal);

	# Instance
	$tmpl = new Ethereal::Template(\%portal);


	# Document header
	print $cgi->header();


	# If undefined list realms, puppets and links
	if (defined($param->{'READONLY'}))
	{ 
		# Flush standard output
		$| = 1;
		print "";

		RealmDisplay($database, $cgi, $param); 
	}

	# Otherwise entrance
	elsif (defined($param->{'ENTRANCE'}))
	{ 
		Entrance($database, $cgi, $param, $tmpl); 
	}

	# Realm selection
	else
	{ 
		RealmSelect($database, $cgi, $param, $tmpl, \%portal); 
	}


#################################################################################
# Sub-Routines
#################################################################################

#####################
# Entrance
#
# The entrace simply lists all people in a room, and the rooms information.  This
# is no different then normal applications

sub Entrance
{
	#####################
	# Data members
	my $database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list
	my $tmpl     = shift;					# Template handler

	my $info;						# Room information
	my $who;						# Who handle


	#####################
	# Program area

	# Cleanup
	$param->Cleanup('ENTRANCE');


	# Display HTML
	# Display header
	$database->DocumentGetHeader();

	# Retreive realm information
	($info) = $database->DataGetRealmDescription($param->{'ROOM'});

	# Wrap with tables
	if (defined($info))
	{
		# Instances
		$who  = new Ethereal::Who($database, $cgi, $param);

		# Wrap with tables
		print "<TABLE WIDTH=\"100%\">\n",
		      " <TR>\n"x
		      "  <TD VALIGN=\"top\">";

		# Retreive realm information
		$tmpl->ShowSub($param->{'ROOM'});
		$who->WhoGuest();

		# Mid section
		print "  </TD>\n",
		      "  <TD VALIGN=\"top\">";

		# Splash page
		print "$info\n";

		# Hind quarter
		print "  </TD>\n",
		      " </TR>\n",
		      "</TABLE>";
        }

	# HTML footer
	$database->DocumentGetFooter();
}

#####################
# Realm Display
#
# Will create a single pane window for use, expressly to be able to view what is
# happening inside the realm.  This differs considerably from normal use. 

sub RealmDisplay						# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list

	my $post;						# Post handle


	#####################
	# Program area

	# Assign a user
	$param->{'USER'} = 'Guest';
	$param->{'CHAR'} = 'Guest';

	# Display HTML
	# Display header
	print $database->FetchRealmHeader($param->{'ROOM'});
	print $database->FetchRealmBanner($param->{'ROOM'});

	# Simply show streaming
	$post = new Ethereal::Post();
	$post->HandleStream($database, $cgi, $param);

	# HTML footer
	print $database->FetchRealmFooter($param->{'ROOM'});;
}

#####################
# Realm Selections
#
# Allows the guest to select a public realm that allows gues access.  This is
# as to allow harser rooms to may be public but do not want the peering eyes
# of guests to see.

sub RealmSelect							# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list
	my $templ    = shift;					# Template instance
	my $portal   = shift;					# Portal hash

	my $inline;						# Inline parameter handling
	my $realms;						# Formatted list of realms
	my $table;						# Table handle	

	my @realms;						# List of realms



	#####################
	# Program area
	
	# Retreive and format values for Realms
	$database->GetListGuestRealms(\@realms);	
	$realms  = $cgi->scrolling_list('ROOM', \@realms, $realms[0], 10);


	# Display HTML and Title
	$database->DocumentGetHeader();

	# Create inline link
	$inline = $param->EmbedInline($param->Flat());

	# Start form
	print $cgi->start_form();
	print $param->EmbedNormal($param->Flat(), 'ENTRANCE', 'true'), "\n";

	# Table handle
	$table = new Ethereal::Table($cgi);

	# Realm Section
	$table->MakeTop();
	$table->MakeSingle($tmpl->PassTitle($portal->{'TagSecRealm'}));
	$table->MakeSingle(
	 $tmpl->Pass('TagLnkGlobalWho',
	  'MLINK',  "$portal->{LnkGlobalWho}$inline",
	  'JSCODE', ''
	  )
	);
	$table->MakeBlank();

	$table->MakeValid($tmpl->PassSub($portal->{'TagSelectRealm'}), $realms);
	$table->MakeBlank();
	
	$table->MakeValid($cgi->submit($portal->{'TxtSubmitRealms'}), $cgi->reset($portal->{'TxtResetRealms'}));
	$table->MakeBottom();

	# End from
	print $cgi->end_form(), "\n";

	# HTML footer
	$database->DocumentGetFooter();
}
