#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 17/11/2002
#################################################################################
#
# Who - Script part of Webchat designed to list who is currently on
# Copyright (C) 2000-2002  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 204 - 817, 5th Street NE
#                 Calgary, Alberta
#                 T2E 3W9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Login;						# Login functionality
use Ethereal::Param;						# Parameter control
use Ethereal::Template;						# Template handler
use Ethereal::Who;						# Who is on


#################################################################################
# Data Members
#################################################################################
my $cgi;							# Common gateway interface handle
my $database;							# Database handle
my $login;							# Login handle
my $param;							# Parameter handle
my $tmpl;							# Template handler
my $who;							# Who is on

my $inline;							# Inline parameters
my $url;							# Self referencing Url

my %login;							# Login hash
my %realm;							# Realm hash


#################################################################################
# Program Area
#################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new Ethereal::Database();

	# Connect and fetch
	$database->Connect();

	# Parameter handling
	$param = new Ethereal::Param($database, $cgi);
	$param->GetParam();

	# Connect with has
	$database->GetHashLogin(\%login);
	$database->GetHashRealm(\%realm);

	# Fetch URL
	$url = $cgi->url();


	# Document header
	print $cgi->header();
	$database->DocumentGetHeader();

	# Login and Who
	$login = new Ethereal::Login($database, $cgi, $param);
	$tmpl  = new Ethereal::Template(\%login);
	$who   = new Ethereal::Who($database, $cgi, $param);

	# Authenthication
	if ($login->GetVerificationNormal())
	{
		# Generate Inline
		$inline = $param->EmbedInline($param->Flat(), 'SYSTEM', 'True');

		# Display title
		$tmpl->ShowMain($realm{'TagTitleWho'});

		# Display
		# Local Realm
		unless (defined($param->{'SYSTEM'}))
		{
			# Show link
			print "<A HREF=\"$url$inline\">$realm{TagLinkSystem}</A>\n<BR>\n";
			
			# Call display
			$who->WhoNormal();		
		}

		# System wide
		else
		{
			# Global who
			$who->WhoAdvanced(\%realm);
		}
	}

	# Document footer
	$database->DocumentGetFooter();
